@@ -187,7 +187,8 @@ def bootstrap_basic(cache=None, registry=None):
     pr.register(r'https?://(?:www\.)?funnyordie\.com/videos/\S+', Provider('http://www.funnyordie.com/oembed'))
 
     # g
-    pr.register(r'https?://gist\.github\.com/\S*', Provider('https://github.com/api/oembed'))
+    # 2020-11-04: removed GitHub gist, as it seems to be unsupported now.
+    #pr.register(r'https?://gist\.github\.com/\S*', Provider('https://github.com/api/oembed'))
 
     # h
     pr.register(r'http://(?:www\.)hulu\.com/watch/\S+', Provider('http://www.hulu.com/api/oembed.json'))
@@ -226,8 +227,8 @@ def bootstrap_basic(cache=None, registry=None):
     pr.register(r'https?://wordpress\.tv/\S+', Provider('http://wordpress.tv/oembed/'))
 
     # y
-    pr.register(r'http://(\S*\.)?youtu(\.be/|be\.com/watch)\S+', Provider('http://www.youtube.com/oembed'))
-    pr.register(r'https://(\S*\.)?youtu(\.be/|be\.com/watch)\S+', Provider('http://www.youtube.com/oembed?scheme=https&'))
+    pr.register(r'http://(\S*\.)?youtu(\.be/|be\.com/watch)\S+', Provider('https://www.youtube.com/oembed'))
+    pr.register(r'https://(\S*\.)?youtu(\.be/|be\.com/watch)\S+', Provider('https://www.youtube.com/oembed?scheme=https&'))
 
     return pr
 
@@ -307,8 +308,8 @@ def bootstrap_oembed(cache=None, registry=None, **params):
     # Currently oembed.com does not provide patterns for YouTube, so we'll add
     # these ourselves.
     pr.register(r'http://(\S*\.)?youtu(\.be/|be\.com/watch)\S+',
-                Provider('http://www.youtube.com/oembed'))
+                Provider('https://www.youtube.com/oembed'))
     pr.register(r'https://(\S*\.)?youtu(\.be/|be\.com/watch)\S+',
-                Provider('http://www.youtube.com/oembed?scheme=https&'))
+                Provider('https://www.youtube.com/oembed?scheme=https&'))
 
     return pr
